# The building of jacoco and jdependency depend on each 
# other. When building jacoco for bootstrap, we use 
# jdependency.jar from maven central repository.
# jacoco => maven-shade-plugin => jdependency => jacoco
%bcond_with bootstrap

%global jdependency_version 2.8.0

Summary:        Code coverage library for Java
Name:           jacoco
Version:        0.8.8
Release:        5%{?dist}
License:        EPL-2.0
URL:            http://www.eclemma.org/%{name}/
Source0:        https://github.com/%{name}/%{name}/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:        https://repo1.maven.org/maven2/org/vafer/jdependency/%{jdependency_version}/jdependency-%{jdependency_version}.jar
Source2:        https://repo1.maven.org/maven2/org/vafer/jdependency/%{jdependency_version}/jdependency-%{jdependency_version}.pom

BuildRequires:  maven-local mvn(args4j:args4j)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-antrun-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-dependency-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-shade-plugin)
BuildRequires:  mvn(org.apache.maven.reporting:maven-reporting-api)
BuildRequires:  mvn(org.codehaus.mojo:build-helper-maven-plugin)
BuildRequires:  mvn(org.codehaus.mojo:exec-maven-plugin)
BuildRequires:  mvn(org.ow2.asm:asm) mvn(org.ow2.asm:asm-analysis)
BuildRequires:  mvn(org.ow2.asm:asm-commons) mvn(org.ow2.asm:asm-tree)
%if %{without bootstrap}
BuildRequires:  mvn(org.vafer:jdependency)
%endif
BuildArch:      noarch

Requires:       javapackages-tools

%description
JaCoCo is a free code coverage library for Java, which has been 
created by the EclEmma team based on the lessons learned from 
using and integration existing libraries over the last five years. 

%package    maven-plugin
Summary:    A Jacoco plugin for maven

%description maven-plugin
A Jacoco plugin for maven.

%{?javadoc_package}

%prep
%autosetup

find -type f '(' -iname '*.jar' -o -iname '*.class' ')' -print -delete

%pom_disable_module ../jacoco org.jacoco.build
%pom_disable_module ../org.jacoco.doc org.jacoco.build
%pom_disable_module ../org.jacoco.examples org.jacoco.build
%pom_disable_module ../org.jacoco.tests org.jacoco.build

%pom_remove_plugin -r :maven-javadoc-plugin
%pom_remove_plugin -r :maven-enforcer-plugin

%pom_remove_plugin :maven-shade-plugin \
    org.jacoco.ant \
    org.jacoco.cli

%pom_remove_plugin -r :spotless-maven-plugin

%pom_remove_plugin :beanshell-maven-plugin \
    org.jacoco.build

%pom_remove_plugin :buildnumber-maven-plugin \
    org.jacoco.build

%pom_xpath_remove 'pom:configuration/pom:instructions/pom:Require-Bundle' \
    org.jacoco.ant

%pom_xpath_remove 'pom:execution[pom:id = "report"]' \
    jacoco-maven-plugin

%pom_xpath_inject 'pom:properties' '
    <unqualifiedVersion>${project.version}</unqualifiedVersion>
    <buildQualifier>${maven.build.timestamp}</buildQualifier>
    <qualified.bundle.version>${unqualifiedVersion}.${buildQualifier}</qualified.bundle.version>
    <jacoco.runtime.package.name>org.jacoco.agent.rt.internal_fedora</jacoco.runtime.package.name>' \
      org.jacoco.build

%mvn_package ":jacoco-maven-plugin:{jar,pom}:{}:" maven-plugin

%mvn_package ":{org.}*:{jar,pom}:runtime:"

%mvn_package :root __noinstall
%mvn_package :org.jacoco.build __noinstall

%if %{with bootstrap}
rm -rf ${HOME}/.m2
mkdir -p ${HOME}/.m2/repository/org/vafer/jdependency/%{jdependency_version}
cp %{SOURCE1} %{SOURCE2} ${HOME}/.m2/repository/org/vafer/jdependency/%{jdependency_version}
%endif

%build
%mvn_build -f -- -Dmaven.compiler.release=8 -Dproject.build.sourceEncoding=UTF-8 -Dbuild.date=$(date +%Y/%m/%d)

%if %{with bootstrap}
rm -rf ${HOME}/.m2/
%endif

%install
%mvn_install

mkdir -p %{buildroot}%{_sysconfdir}/ant.d
echo %{name} %{name}/org.jacoco.ant objectweb-asm/asm > %{buildroot}%{_sysconfdir}/ant.d/%{name}

%jpackage_script org.jacoco.cli.internal.Main "" "" jacoco/org.jacoco.cli:args4j:objectweb-asm:jacoco/org.jacoco.core:jacoco/org.jacoco.report jacococli true

%files -f .mfiles
%license LICENSE.md
%doc README.md
%config(noreplace) %{_sysconfdir}/ant.d/%{name}
%{_bindir}/jacococli

%files maven-plugin -f .mfiles-maven-plugin

%changelog
* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.8.8-5
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.8.8-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.8.8-3
- Rebuilt for OpenCloudOS Stream 23.05

* Wed Apr 26 2023 Xiaojie Chen <jackxjchen@tencent.com> - 0.8.8-2
- Disable bootstrap

* Tue Apr 25 2023 Xiaojie Chen <jackxjchen@tencent.com> - 0.8.8-1
- Initial build
